pylbm.elements.Cylinder\_Circle
===============================

.. currentmodule:: pylbm.elements

.. autoclass:: Cylinder_Circle

   

   .. HACK -- the point here is that we don't want this to appear in the output, but the autosummary should still generate the pages.
      .. autosummary::
         :toctree:
      
         Cylinder_Circle.change_of_variables
         Cylinder_Circle.distance
         Cylinder_Circle.get_bounds
         Cylinder_Circle.point_inside
         Cylinder_Circle.test_label



   

